@@ -1,16 +1,14 @@
 """This package contains utility mixins"""
 # pylint: disable=too-few-public-methods
 from abc import ABCMeta
+from typing import Any
 
 
-class SimpleEquality(object):
+class SimpleEquality(metaclass=ABCMeta):
     """Naive __dict__ equality mixin"""
 
-    __metaclass__ = ABCMeta
-
-    def __eq__(self, other):
-        return (isinstance(other, self.__class__)
-                and self.__dict__ == other.__dict__)
+    def __eq__(self, other: Any) -> bool:
+        return isinstance(other, self.__class__) and self.__dict__ == other.__dict__
 
     def __ne__(self, other):
         return not self.__eq__(other)
